@@ -1,5 +1,4 @@
 """Unicode Properties from Unicode version 13.0.0 (autogen)."""
-from __future__ import unicode_literals
 
 unicode_alias = {
     "_": {
@@ -88,7 +87,6 @@ unicode_alias = {
     },
     "binary": {
         "ahex": "asciihexdigit",
-        "alnum": "posixalnum",
         "alpha": "alphabetic",
         "bidic": "bidicontrol",
         "bidim": "bidimirrored",
@@ -141,6 +139,10 @@ unicode_alias = {
         "patsyn": "patternsyntax",
         "patws": "patternwhitespace",
         "pcm": "prependedconcatenationmark",
+        "posixalpha": "alphabetic",
+        "posixlower": "lowercase",
+        "posixspace": "whitespace",
+        "posixupper": "uppercase",
         "print": "posixprint",
         "qmark": "quotationmark",
         "radical": "radical",
@@ -153,7 +155,6 @@ unicode_alias = {
         "upper": "uppercase",
         "vs": "variationselector",
         "wspace": "whitespace",
-        "xdigit": "posixxdigit",
         "xidc": "xidcontinue",
         "xids": "xidstart"
     },
@@ -462,7 +463,7 @@ unicode_alias = {
     "indicsyllabiccategory": {
     },
     "joininggroup": {
-        "tehmarbutagoal": "hamzaonhehgoal"
+        "hamzaonhehgoal": "tehmarbutagoal"
     },
     "joiningtype": {
         "dualjoining": "d",
@@ -473,44 +474,44 @@ unicode_alias = {
         "transparent": "t"
     },
     "linebreak": {
-        "ai": "ambiguous",
-        "al": "alphabetic",
-        "b2": "breakboth",
-        "ba": "breakafter",
-        "bb": "breakbefore",
-        "bk": "mandatorybreak",
-        "cb": "contingentbreak",
-        "cj": "conditionaljapanesestarter",
-        "cl": "closepunctuation",
-        "cm": "combiningmark",
-        "cp": "closeparenthesis",
-        "cr": "carriagereturn",
-        "eb": "ebase",
-        "em": "emodifier",
-        "ex": "exclamation",
-        "gl": "glue",
-        "hl": "hebrewletter",
-        "hy": "hyphen",
-        "id": "ideographic",
-        "in": "inseparable",
-        "inseperable": "inseparable",
-        "is": "infixnumeric",
-        "lf": "linefeed",
-        "nl": "nextline",
-        "ns": "nonstarter",
-        "nu": "numeric",
-        "op": "openpunctuation",
-        "po": "postfixnumeric",
-        "pr": "prefixnumeric",
-        "qu": "quotation",
-        "ri": "regionalindicator",
-        "sa": "complexcontext",
-        "sg": "surrogate",
-        "sp": "space",
-        "sy": "breaksymbols",
-        "wj": "wordjoiner",
-        "xx": "unknown",
-        "zw": "zwspace"
+        "alphabetic": "al",
+        "ambiguous": "ai",
+        "breakafter": "ba",
+        "breakbefore": "bb",
+        "breakboth": "b2",
+        "breaksymbols": "sy",
+        "carriagereturn": "cr",
+        "closeparenthesis": "cp",
+        "closepunctuation": "cl",
+        "combiningmark": "cm",
+        "complexcontext": "sa",
+        "conditionaljapanesestarter": "cj",
+        "contingentbreak": "cb",
+        "ebase": "eb",
+        "emodifier": "em",
+        "exclamation": "ex",
+        "glue": "gl",
+        "hebrewletter": "hl",
+        "hyphen": "hy",
+        "ideographic": "id",
+        "infixnumeric": "is",
+        "inseparable": "in",
+        "inseperable": "in",
+        "linefeed": "lf",
+        "mandatorybreak": "bk",
+        "nextline": "nl",
+        "nonstarter": "ns",
+        "numeric": "nu",
+        "openpunctuation": "op",
+        "postfixnumeric": "po",
+        "prefixnumeric": "pr",
+        "quotation": "qu",
+        "regionalindicator": "ri",
+        "space": "sp",
+        "surrogate": "sg",
+        "unknown": "xx",
+        "wordjoiner": "wj",
+        "zwspace": "zw"
     },
     "nfcquickcheck": {
         "maybe": "m",
@@ -736,56 +737,3 @@ unicode_alias = {
         "xx": "other"
     }
 }
-enum_names = {
-    "age",
-    "bc",
-    "bidiclass",
-    "bidipairedbrackettype",
-    "blk",
-    "block",
-    "bpt",
-    "canonicalcombiningclass",
-    "ccc",
-    "decompositiontype",
-    "dt",
-    "ea",
-    "eastasianwidth",
-    "gc",
-    "gcb",
-    "generalcategory",
-    "graphemeclusterbreak",
-    "hangulsyllabletype",
-    "hst",
-    "indicpositionalcategory",
-    "indicsyllabiccategory",
-    "inpc",
-    "insc",
-    "jg",
-    "joininggroup",
-    "joiningtype",
-    "jt",
-    "lb",
-    "linebreak",
-    "nfcqc",
-    "nfcquickcheck",
-    "nfdqc",
-    "nfdquickcheck",
-    "nfkcqc",
-    "nfkcquickcheck",
-    "nfkdqc",
-    "nfkdquickcheck",
-    "nt",
-    "numerictype",
-    "numericvalue",
-    "nv",
-    "sb",
-    "sc",
-    "script",
-    "scriptextensions",
-    "scx",
-    "sentencebreak",
-    "verticalorientation",
-    "vo",
-    "wb",
-    "wordbreak"
-}
